@@ -22,10 +22,6 @@ static void addCredits (KAboutData & about);
 
 int main (int argc, char **argv)
 {
-    // Fixes blurry icons with fractional scaling
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain("kgoldrunner");
@@ -39,12 +35,15 @@ int main (int argc, char **argv)
                      QStringLiteral("https://apps.kde.org/kgoldrunner") );
     addCredits (about);
 
-    QCommandLineParser parser;
     KAboutData::setApplicationData(about);
+
     KCrash::initialize();
+
+    QCommandLineParser parser;
     about.setupCommandLine(&parser);
     parser.process(app);
     about.processCommandLine(&parser);
+
     KDBusService service;
 
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kgoldrunner")));
